@@ -1762,8 +1762,8 @@ void intel_psr_atomic_check(struct drm_connector *connector,
 		return;
 
 	intel_connector = to_intel_connector(connector);
-	dig_port = enc_to_dig_port(intel_attached_encoder(intel_connector));
-	if (!dig_port || dev_priv->psr.dp != &dig_port->dp)
+	dig_port = enc_to_dig_port(to_intel_encoder(new_state->best_encoder));
+	if (dev_priv->psr.dp != &dig_port->dp)
 		return;
 
 	crtc_state = drm_atomic_get_new_crtc_state(new_state->state,
